@@ -1,4 +1,4 @@
-// $Id: VPreproc.cpp 19676 2006-05-08 19:03:42Z wsnyder $  -*- C++ -*-
+// $Id: VPreproc.cpp 25396 2006-09-14 14:47:39Z wsnyder $  -*- C++ -*-
 //*************************************************************************
 //
 // Copyright 2000-2006 by Wilson Snyder.  This program is free software;
@@ -323,6 +323,7 @@ void VPreprocImp::open(string filename, VFileLine* filelinep) {
 
     m_lexp = new VPreprocLex (fp);
     m_lexp->m_keepComments = m_preprocp->keepComments();
+    m_lexp->m_keepWhitespace = m_preprocp->keepWhitespace();
     m_lexp->m_pedantic = m_preprocp->pedantic();
     m_lexp->m_curFilelinep = m_preprocp->filelinep()->create(filename, 1);
     m_filelinep = m_lexp->m_curFilelinep;  // Remember token start location
@@ -384,10 +385,12 @@ int VPreprocImp::getRawToken() {
 	int tok = yylex();
 
 	if (debug()) {
-	    char buf[10000]; strncpy(buf, yytext, yyleng);  buf[yyleng] = '\0';
-	    for (char* cp=buf; *cp; cp++) if (*cp=='\n') *cp='$';
+	    string buf = string (yytext, yyleng);
+	    string::size_type pos;
+	    while ((pos=buf.find("\n")) != string::npos) { buf.replace(pos, 1, "\\n"); }
+	    while ((pos=buf.find("\r")) != string::npos) { buf.replace(pos, 1, "\\r"); }
 	    fprintf (stderr,"%d: RAW %d %d:  %-10s: %s\n",
-		     m_filelinep->lineno(), m_off, m_state, tokenName(tok), buf);
+		     m_filelinep->lineno(), m_off, m_state, tokenName(tok), buf.c_str());
 	}
     
 	// On EOF, try to pop to upper level includes, as needed.
@@ -707,30 +710,41 @@ int VPreprocImp::getToken() {
 string VPreprocImp::getline() {
     // Get a single line from the parse stream.  Buffer unreturned text until the newline.
     if (isEof()) return "";
-    char* rtnp;
-    while (NULL==(rtnp=strchr(m_lineChars.c_str(),'\n'))) {
-	int tok = getToken();
-	if (debug()) {
-	    char buf[100000];
-	    strncpy(buf, yytext, yyleng);
-	    buf[yyleng] = '\0';
-	    for (char* cp=buf; *cp; cp++) if (*cp=='\n') *cp='$';
-	    fprintf (stderr,"%d: GETFETC:  %-10s: %s\n",
-		     m_filelinep->lineno(), tokenName(tok), buf);
+    while (1) {
+	char* rtnp;
+	bool gotEof = false;
+	while (NULL==(rtnp=strchr(m_lineChars.c_str(),'\n'))) {
+	    int tok = getToken();
+	    if (debug()) {
+		string buf = string (yytext, yyleng);
+		string::size_type pos;
+		while ((pos=buf.find("\n")) != string::npos) { buf.replace(pos, 1, "\\n"); }
+		while ((pos=buf.find("\r")) != string::npos) { buf.replace(pos, 1, "\\r"); }
+		fprintf (stderr,"%d: GETFETC:  %-10s: %s\n",
+			 m_filelinep->lineno(), tokenName(tok), buf.c_str());
+	    }
+	    if (tok==VP_EOF) {
+		// Add a final newline, in case the user forgot the final \n.
+		m_lineChars.append("\n");
+		gotEof = true;
+	    }
+	    else {
+		m_lineChars.append(yytext,0,yyleng);
+	    }
 	}
-	if (tok==VP_EOF) {
-	    // Add a final newline, in case the user forgot the final \n.
-	    m_lineChars.append("\n");
-	}
-	else {
-	    m_lineChars.append(yytext,0,yyleng);
-	}
-    }
 
-    // Make new string with data up to the newline.
-    int len = rtnp-m_lineChars.c_str()+1;
-    string theLine(m_lineChars, 0, len);
-    m_lineChars = m_lineChars.erase(0,len);	// Remove returned characters
-    if (debug()) fprintf (stderr,"%d: GETLINE:  %s\n", m_filelinep->lineno(), theLine.c_str());
-    return theLine;
+	// Make new string with data up to the newline.
+	int len = rtnp-m_lineChars.c_str()+1;
+	string theLine(m_lineChars, 0, len);
+	m_lineChars = m_lineChars.erase(0,len);	// Remove returned characters
+
+	if (!m_preprocp->keepWhitespace() && !gotEof) {
+	    const char* cp=theLine.c_str();
+	    for (; *cp && (isspace(*cp) || *cp=='\n'); cp++) {}
+	    if (!*cp) continue;
+	}
+
+	if (debug()) fprintf (stderr,"%d: GETLINE:  %s\n", m_filelinep->lineno(), theLine.c_str());
+	return theLine;
+    }
 }
